@@ -45,7 +45,7 @@ def plot_graph(gin, plotpath, shppath=''):
     """Plot the graph @gin and export to @plotpath and, if provided, plot
     the border given by @shppath"""
     if type(g) == str:
-        g = simplify_graphml(g, directed=False, simplify=True)
+        g = simplify_graphml(gin, directed=False, simplify=True)
     else:
         g = gin
 
